@@ -321,7 +321,7 @@ class writePending(object):
             print(command)
         else:
             self.MdB.exec_dB(command, commit=True)
-            res, N = self.MdB.select_dB(select_='last_insert_id()', from_=self.table, format_ = 'dict2')
+            res, N = self.MdB.select_dB(select_='last_insert_id()', from_=self.table, format_ = 'dict2', commit=True)
             self.last_N = res['last_insert_id()'][0]
             command = 'UPDATE {0} SET FILE="{1}_{2}" WHERE N={2};'.format(self.table, self._dic['file'], 
                                                                           self.last_N)
@@ -407,7 +407,8 @@ class writeTab(object):
             self.log_.error('Not connected')
             return None
         
-        res, Nres = self.MdB.select_dB(select_='*', from_=self.pending_table, where_='N = {0}'.format(N_pending))
+        res, Nres = self.MdB.select_dB(select_='*', from_=self.pending_table, 
+                                       where_='N = {0}'.format(N_pending), commit=True)
         self.update_status('Read_pending2')
         self.pending = res[0]
 
@@ -662,7 +663,7 @@ class runCloudy(object):
             self.log_.error('Not connected')
         try:
             res, N = self.MdB.select_dB(select_ = 'N, priority', from_ = self.pending_table, 
-                                       where_ = 'status = 0', limit_=None, format_='numpy')
+                                       where_ = 'status = 0', limit_=None, format_='numpy', commit=True)
         except:
             self.log_.error('Error looking for status=0 models in {0}'.format(self.pending_table), 
                           calling='runCloudy.select_pending')
@@ -706,7 +707,7 @@ class runCloudy(object):
         else:
             self.selectedN = N_pending
         res, Nres = self.MdB.select_dB(select_='*', from_=self.pending_table, 
-                                       where_='N = {0}'.format(N_pending))
+                                       where_='N = {0}'.format(N_pending), commit=True)
         
         self.update_status('Read_pending')
         if Nres == 0:
@@ -1068,7 +1069,8 @@ def print_all_refs(MdB = None, OVN_dic=None):
         MdB = pc.MdB(OVN_dic=OVN_dic)
     if not isinstance(MdB, pc.MdB):
         self.log_.error('The first argument must be a MdB object')    
-    res, N_ref = MdB.select_dB(select_ = 'distinct(ref), count(*)', from_ = OVN_dic['master_table'], group_ = 'ref', limit_ = None)
+    res, N_ref = MdB.select_dB(select_ = 'distinct(ref), count(*)', from_ = OVN_dic['master_table'], 
+                               group_ = 'ref', limit_ = None)
     for row in res:
         print('The ref "{0:15}" counts {1:8d} entries.'.format(row['ref'], row['count(*)']))
     print('Number of distinct references = {0}'.format(N_ref))
@@ -1100,7 +1102,7 @@ def print_status_stats(MdB = None, OVN_dic=None, ref_=None):
     else:
         where_ = None
     res, N_res = MdB.select_dB(select_='status, count(*) as ct',from_=OVN_dic['pending_table'],
-                               where_=where_, group_='status', limit_=None)
+                               where_=where_, group_='status', limit_=None, commit=True)
     for status in res: 
         print('{0:7} models with status = {1:4}.'.format(status['ct'], status['status']))
 
@@ -1150,10 +1152,10 @@ def print_ETA(MdB= None, OVN_dic=None, ref_=None):
     else:
         where_ = ''
     res, N_res = MdB.select_dB(select_='count(*)',from_=OVN_dic['pending_table'],
-                               where_=where_ + ' AND status=0', limit_=None)
+                               where_=where_ + ' AND status=0', limit_=None, commit=True)
     N_pending = res[0]['count(*)']
     res, N_res = MdB.select_dB(select_='count(*)',from_=OVN_dic['pending_table'],
-                               where_=where_ + 'AND status=50', limit_=None)
+                               where_=where_ + 'AND status=50', limit_=None, commit=True)
     N_run = res[0]['count(*)']
     res, N_res = MdB.select_dB(select_='time_to_sec(timediff(max(datetime),min(datetime))) as ET',
                                from_=OVN_dic['master_table'], where_=where_, limit_=None)
@@ -1172,7 +1174,7 @@ def print_efficiency(MdB= None, OVN_dic=None, ref_=None):
     else:
         where_ = ''
     res, N_res = MdB.select_dB(select_='count(*)',from_=OVN_dic['pending_table'],
-                               where_=where_ + 'AND status=50', limit_=None)
+                               where_=where_ + 'AND status=50', limit_=None, commit=True)
     N_run = res[0]['count(*)']
     res, N_res = MdB.select_dB(select_='time_to_sec(timediff(max(datetime),min(datetime))) as ET',
                                from_=OVN_dic['master_table'], where_=where_, limit_=None)
@@ -1197,10 +1199,10 @@ def print_infos(MdB= None, OVN_dic=None, ref_=None, where_=None, Nprocs=32):
     if where_ is not None:
         this_where_ += ' AND {}'.format(where_)
     res, N_res = MdB.select_dB(select_='count(*)',from_=OVN_dic['pending_table'],
-                               where_=this_where_ + ' AND status=0', limit_=None)
+                               where_=this_where_ + ' AND status=0', limit_=None, commit=True)
     N_pending = res[0]['count(*)']
     res, N_res = MdB.select_dB(select_='count(*)',from_=OVN_dic['pending_table'],
-                               where_=this_where_ + 'AND status=50', limit_=None)
+                               where_=this_where_ + 'AND status=50', limit_=None, commit=True)
     N_run = res[0]['count(*)']
     if N_run == 0 and N_pending == 0:
         print('No entry')
